@@ -88,8 +88,9 @@ void usage()
 	    "<options> are:\n"
 	    "              [-display <display>] [-shared]\n"
 	    "              [-north] [-south] [-east] [-west]\n"
-	    "              [-passwd <passwd-file>]\n"
+	    "              [-passwd <passwd-file>] [-version]\n"
 	    "              [-resurface] [-edgewidth width]\n"
+	    "              [-nowheel]\n"
 	    ,programName,programName);
     exit(1);
 }
@@ -118,6 +119,9 @@ processArgs(int argc, char **argv)
 	  edge=EDGE_NORTH;
 	} else if (strcmp(argv[i],"-south") == 0) {
 	  edge=EDGE_SOUTH;
+	} else if (strcmp(argv[i],"-nowheel") == 0) {
+	  extern int emulate_wheel;
+	  emulate_wheel=0;
 	} else if (strcmp(argv[i],"-resurface") == 0) {
 	  resurface=True;
 	} else if (strcmp(argv[i],"-shared") == 0) {
