@@ -170,6 +170,17 @@ InitialiseRFBConnection(int sock)
 	  if (!(passwd = vncDecryptPasswdFromFile(passwdFile))) {
 	    fprintf(stderr,"%s: Couldn't open password file: %s\n",
 		    programName, passwdFile);
+	    fprintf(stderr,"If you wish to create this password file, enter a password below.\n");
+	    passwd = getpass("Password: ");
+
+	    if (!passwd || strlen(passwd) == 0) {
+		fprintf(stderr,"%s: Reading password failed\n",programName);
+		return False;
+	    }
+	    if (strlen(passwd) > 8) {
+		passwd[8] = '\0';
+	    }
+	    vncEncryptAndStorePasswd(passwd, passwdFile);
 	    return False;
 	  }
 	} else {
@@ -348,7 +359,6 @@ SendKeyEvent(CARD32 key, Bool down)
 {
     rfbKeyEventMsg ke;
 
-
     ke.type = rfbKeyEvent;
     ke.down = down ? 1 : 0;
     ke.key = Swap32IfLE(key);
