@@ -50,6 +50,7 @@ enum edge_enum edge = EDGE_EAST;
 int edge_width=1;
 int restingx=-1;
 int restingy=-1;
+int emulate_wheel=1;
 
 /*
  * This variable is true (1) if the mouse is on the same screen as the one
@@ -447,7 +448,8 @@ HandleTopLevelEvent(XEvent *ev)
               
         }
           
-	if(d) {
+	if(d)
+	{
 	  SendPointerEvent(restingx,restingy,0);
 	  XWarpPointer(dpy,None, warpWindow, 0,0,0,0, x, y);
 	  XUngrabKeyboard(dpy, CurrentTime);
@@ -455,7 +457,7 @@ HandleTopLevelEvent(XEvent *ev)
           mouseOnScreen = warpWindow == DefaultRootWindow(dpy);
 	  XFlush(dpy);
 	  
-	  for (i = 0; i < 256; i++) {
+	  for (i = 255; i >= 0; i--) {
 	    if (modifierPressed[i]) {
 	      if (!SendKeyEvent(XKeycodeToKeysym(dpy, i, 0), False))
 		return False;
@@ -471,6 +473,20 @@ HandleTopLevelEvent(XEvent *ev)
       
     case ButtonPress:
     case ButtonRelease:
+      if (ev->xbutton.button > 3 && emulate_wheel)
+      {
+	if (ev->xbutton.button == 4)
+	  ks = XK_Down;
+	else
+	  ks = XK_Up;
+
+	if (ev->type == ButtonPress)
+	  SendKeyEvent(ks, 1); /* keydown */
+	else
+	  SendKeyEvent(ks, 0); /* keyup */
+	break;
+      }
+
       if (ev->type == ButtonPress) {
 	buttonMask = (((ev->xbutton.state & 0x1f00) >> 8) |
 		      (1 << (ev->xbutton.button - 1)));
@@ -482,7 +498,7 @@ HandleTopLevelEvent(XEvent *ev)
       return SendPointerEvent(SCALEX(ev->xbutton.x_root),
 			      SCALEY(ev->xbutton.y_root),
 			      buttonMask);
-      
+	
     case KeyPress:
     case KeyRelease:
     {
@@ -498,6 +514,9 @@ HandleTopLevelEvent(XEvent *ev)
 	/* This fixes the 'shift-tab' problem - Hubbe */
 	switch(ks)
 	{
+#if XK_ISO_Left_Tab != 0x10000ff74
+	  case 0x10000ff74: /* HP-UX */
+#endif
 	  case XK_ISO_Left_Tab: ks=XK_Tab; break;
 	}
       }
